@@ -185,8 +185,7 @@ class FilterSeen(object):
                                  (found.field, found.value, se.task, se.added.strftime('%Y-%m-%d %H:%M')),
                                 remember=remember_rejected)
 
-    @plugin.priority(-255)
-    def on_task_output(self, task, config):
+    def on_task_learn(self, task, config):
         """Remember succeeded entries"""
         if config is False:
             log.debug('disabled')
